@@ -277,7 +277,8 @@ class TestCinderStoreBase(object):
                 mock.patch.object(socket,
                                   'gethostname') as mock_get_host, \
                 mock.patch.object(socket,
-                                  'getaddrinfo') as mock_get_host_ip:
+                                  'getaddrinfo') as mock_get_host_ip, \
+                mock.patch.object(cinder.strutils, 'mask_dict_password'):
 
             fake_host = 'fake_host'
             fake_addr_info = [[0, 1, 2, 3, ['127.0.0.1']]]
@@ -314,7 +315,7 @@ class TestCinderStoreBase(object):
                     fake_connector.connect_volume.assert_called_once_with(
                         mock.ANY)
                     fake_connector.disconnect_volume.assert_called_once_with(
-                        mock.ANY, fake_devinfo)
+                        mock.ANY, fake_devinfo, force=True)
                     fake_conn_obj.assert_called_once_with(
                         mock.ANY, root_helper, conn=mock.ANY,
                         use_multipath=multipath_supported)
